<?php
/**
 * Thehideout functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package thehideout
 */

if ( ! defined( 'THEHIDEOUT_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'THEHIDEOUT_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function thehideout_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on thehideout, use a find and replace
		* to change 'thehideout' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'thehideout', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );


	/**
		* This theme uses wp_nav_menu() in one location.
		*/
	function thehideout_theme_menus(){
	
		register_nav_menus(array(
			"header"=>"Header Menu",
			"footer"=>"Footer Menu"
		));
	}
	add_action("init","thehideout_theme_menus");

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'thehideout_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 50,
			'width'       => 50,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'thehideout_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function thehideout_content_width() {
	$GLOBALS['thehideout_content_width'] = apply_filters( 'thehideout_content_width', 640 );
}
add_action( 'after_setup_theme', 'thehideout_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function thehideout_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'thehideout' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'thehideout' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'thehideout_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
function thehideout_scripts() {
wp_enqueue_style( 'dashicons' );
	wp_enqueue_style( 'thehideout-style.css', get_stylesheet_directory_uri()."/assets/css/thehideout-style.css",'',THEHIDEOUT_S_VERSION );

	wp_enqueue_style( 'thehideout-bootstrap.min.css', get_stylesheet_directory_uri()."/assets/css/thehideout-bootstrap.min.css",'',THEHIDEOUT_S_VERSION );

	wp_enqueue_style( 'thehideout-font.css', get_stylesheet_directory_uri()."/assets/css/thehideout-font.css",'',THEHIDEOUT_S_VERSION );

	wp_enqueue_script( 'jquery');
	wp_enqueue_script( 'thehideout.navigation.js', get_stylesheet_directory_uri() . '/js/navigation.js', array(), THEHIDEOUT_S_VERSION, true );
	wp_enqueue_script( 'thehideout-jquery.min.js', get_stylesheet_directory_uri() . '/assets/js/thehideout-jquery.min.js', array(), THEHIDEOUT_S_VERSION, true );
	wp_enqueue_script( 'thehideout-jquery.slim.min.js', get_stylesheet_directory_uri() . '/assets/js/thehideout-jquery.slim.min.js', array(), THEHIDEOUT_S_VERSION, true );
	wp_enqueue_script( 'bootstrap.min.js', get_stylesheet_directory_uri() . '/assets/js/bootstrap.min.js', array(), THEHIDEOUT_S_VERSION, true );
	wp_enqueue_script( 'thehideout-fontawesome', get_stylesheet_directory_uri() . '/assets/js/fontawesome.js', array(), THEHIDEOUT_S_VERSION, true );
	wp_enqueue_script( 'thehideout-custom', get_stylesheet_directory_uri() . '/assets/js/custom.js', array(), THEHIDEOUT_S_VERSION, true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 'thehideout_scripts');

/**
 * Customizer
 */
function thehideout_customizer_setting($wp_customize) {	

	$wp_customize->add_panel(
        'thehideout_section_panel',
        [
           'priority' => 30,
           'capability' => 'edit_theme_options',
           'title' => esc_html__('TheHideOut Section', 'thehideout'),
        ]
    );

    $wp_customize->add_section( 'thehideout_section' , array(

	'title'      => esc_html__( 'HomeSection', 'thehideout' ),
	'capability' => 'edit_theme_options',
	'panel' => 'thehideout_section_panel'

	) );

	$wp_customize->add_section( 'thehideout_section_about' , array(

	'title'      => esc_html__( 'AboutSection', 'thehideout' ),
	'capability' => 'edit_theme_options',
	'panel' => 'thehideout_section_panel'

	) );
	//Home Section
	$wp_customize->add_setting( 'thehideout_homesection_display' , array(

	'default'   => 'No',

	'sanitize_callback' => 'thehideout_sanitise_custom_option',

	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'thehideout_homesection_display_control', array(

	'label'      => esc_html__( 'Diaplay this section', 'thehideout' ),

	'section'    => 'thehideout_section',

	'settings'   => 'thehideout_homesection_display',

	'type' => 'select',
    	
    'choices' => array('No' => 'No', 'Yes' => 'Yes')

	) ) );


	$wp_customize->add_setting( 'thehideout_homesection_text' , array(

	'default'   => '',

	'sanitize_callback' => 'thehideout_sanitise_custom_text',

	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'thehideout_homesection_text_control', array(

	'label'      => esc_html__( 'Home Text', 'thehideout' ),

	'section'    => 'thehideout_section',

	'settings'   => 'thehideout_homesection_text',

	'type' => 'textarea',   	
    

	) ) );

	$wp_customize->add_setting( 'thehideout_homesection_image' , array(

	'sanitize_callback' => 'thehideout_sanitise_custom_url',

	'capability' => 'edit_theme_options',

	'type' => 'theme_mod',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'thehideout_homesection_image_control', array(

	'label'      => esc_html__( 'Home Image', 'thehideout' ),

	'section'    => 'thehideout_section',

	'settings'   => 'thehideout_homesection_image',
	) ) );

	//About Section
	//Display
	$wp_customize->add_setting( 'thehideout_aboutsection_display' , array(

	'default'   => 'No',

	'sanitize_callback' => 'thehideout_sanitise_custom_option',

	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'thehideout_aboutsection_display_control', array(

	'label'      => esc_html__( 'Diaplay this section', 'thehideout' ),

	'section'    => 'thehideout_section_about',

	'settings'   => 'thehideout_aboutsection_display',

	'type' => 'select',
    	
    'choices' => array('No' => 'No', 'Yes' => 'Yes')

	) ) );

	//Title

	$wp_customize->add_setting( 'thehideout_aboutsection_texttitle' , array(

	'default'   => '',

	'sanitize_callback' => 'thehideout_sanitise_custom_texttitle',

	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'thehideout_aboutsection_texttitle_control', array(

	'label'      => esc_html__( 'Title', 'thehideout' ),

	'section'    => 'thehideout_section_about',

	'settings'   => 'thehideout_aboutsection_texttitle',

	'type' => 'text',   	
    

	) ) );

	//Text

	$wp_customize->add_setting( 'thehideout_about_text' , array(

	'default'   => '',

	'sanitize_callback' => 'thehideout_sanitise_custom_text',

	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'thehideout_about_text', array(

	'label'      => esc_html__( 'Text', 'thehideout' ),

	'section'    => 'thehideout_section_about',

	'settings'   => 'thehideout_about_text',

	'type' => 'textarea',   	
    

	) ) );

	//Image

	$wp_customize->add_setting( 'thehideout_aboutsection_image' , array(
		'default' => 'post',

	'sanitize_callback' => 'thehideout_sanitise_custom_url',

	'capability' => 'edit_theme_options',

	'type' => 'theme_mod',

	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'thehideout_aboutsection_image_control', array(

	'label'      => esc_html__( 'Image', 'thehideout' ),

	'section'    => 'thehideout_section_about',

	'settings'   => 'thehideout_aboutsection_image',

	
	) ) );

	//Footer Text
	$wp_customize->add_panel(
        'thehideout_theme_section_panel',
        [
           'priority' => 30,
           'capability' => 'edit_theme_options',
           'title' => esc_html__('Theme Option Section', 'thehideout'),
        ]
    );

    $wp_customize->add_section( 'thehideout_footer_section' , array(

	'title'      => esc_html__( 'Footer Section', 'thehideout' ),
	'capability' => 'edit_theme_options',
	'panel' => 'thehideout_theme_section_panel'

	) );


	$wp_customize->add_setting( 'thehideout_footertext_setting' , array(

	'default'   => esc_html__('TheHideOut WordPress Theme by','thehideout'),

	'sanitize_callback' => 'thehideout_sanitise_custom_text',

	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'thehideout_aboutsection_text_control', array(

	'label'      => esc_html__( 'Footer Text', 'thehideout' ),

	'section'    => 'thehideout_footer_section',

	'settings'   => 'thehideout_footertext_setting',
    

	) ) );

	$wp_customize->add_setting( 'thehideout_footer_authortext_setting' , array(

	'default'   => esc_html__('Appnotick','thehideout'),

	'sanitize_callback' => 'thehideout_sanitise_custom_text',

	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'thehideout_footerauthor_text_control', array(

	'label'      => esc_html__( 'Author Text', 'thehideout' ),

	'section'    => 'thehideout_footer_section',

	'settings'   => 'thehideout_footer_authortext_setting',
    

	) ) );

	$wp_customize->add_section(
	'thehideout_post_options',
	array(
		'title' => esc_html__( 'Post Options', 'thehideout' ),
		'panel' => 'thehideout_theme_section_panel',
		)
	);

	// Post Options - Hide Date.
	$wp_customize->add_setting(
		'thehideout_post_hide_date',
		array(
			'default'           => false,
			'sanitize_callback' => 'thehideout_sanitize_switch',
		)
	);

	$wp_customize->add_control(
		new Thehideout_Toggle_Switch_Custom_Control(
			$wp_customize,
			'thehideout_post_hide_date',
			array(
				'label'   => esc_html__( 'Hide Date', 'thehideout' ),
				'section' => 'thehideout_post_options',
			)
		)
	);

	// Post Options - Hide Author.
	$wp_customize->add_setting(
		'thehideout_post_hide_author',
		array(
			'default'           => false,
			'sanitize_callback' => 'thehideout_sanitize_switch',
		)
	);

	$wp_customize->add_control(
		new Thehideout_Toggle_Switch_Custom_Control(
			$wp_customize,
			'thehideout_post_hide_author',
			array(
				'label'   => esc_html__( 'Hide Author', 'thehideout' ),
				'section' => 'thehideout_post_options',
			)
		)
	);

	// Post Options - Hide Category.
	$wp_customize->add_setting(
		'thehideout_post_hide_category',
		array(
			'default'           => false,
			'sanitize_callback' => 'thehideout_sanitize_switch',
		)
	);

	$wp_customize->add_control(
		new Thehideout_Toggle_Switch_Custom_Control(
			$wp_customize,
			'thehideout_post_hide_category',
			array(
				'label'   => esc_html__( 'Hide Category', 'thehideout' ),
				'section' => 'thehideout_post_options',
			)
		)
	);

	function thehideout_sanitise_custom_option($input){
		return ($input === "No") ? "No" : "Yes";
	}

	function thehideout_sanitise_custom_text($input){
		return filter_var($input, FILTER_SANITIZE_STRING);
	}

	function thehideout_sanitise_custom_texttitle($inputtitle){
		return filter_var($inputtitle, FILTER_SANITIZE_STRING);
	}

	function thehideout_sanitise_custom_url($input){
		return filter_var($input, FILTER_SANITIZE_URL);
	}

	function thehideout_sanitize_switch( $input ) {
		if ( true === $input ) {
			return true;
		} else {
			return false;
		}
	}

	
}

add_action('customize_register', 'thehideout_customizer_setting');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/custom-control/custom-control.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}


function thehideout_add_menu_parent_class( $items ) {
 
 $parents = array();
 foreach ( $items as $item ) {
 if ( $item->menu_item_parent && $item->menu_item_parent > 0 ) {
 $parents[] = $item->menu_item_parent;
 }
 }
 
 foreach ( $items as $item ) {
 if ( in_array( $item->ID, $parents ) ) {
 $item->classes[] = 'has-children';
 }
 }
 
 return $items;
}
add_filter( 'wp_nav_menu_objects', 'thehideout_add_menu_parent_class' );


